"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const shuffle = require("lodash.shuffle");
exports.selectPeersForRequest = (input) => {
    const { peers, nodeInfo } = input;
    const peerLimit = input.peerLimit;
    const nodeHeight = nodeInfo ? nodeInfo.height : 0;
    const filteredPeers = peers.filter((peer) => peer.height >= nodeHeight);
    if (filteredPeers.length === 0) {
        return [];
    }
    const sortedPeers = filteredPeers.sort((a, b) => b.height - a.height);
    const aggregation = 2;
    const calculatedHistogramValues = sortedPeers.reduce((histogramValues, peer) => {
        const val = Math.floor(peer.height / aggregation) * aggregation;
        histogramValues.histogram[val] =
            (histogramValues.histogram[val] ? histogramValues.histogram[val] : 0) +
                1;
        if (histogramValues.histogram[val] > histogramValues.max) {
            histogramValues.max = histogramValues.histogram[val];
            histogramValues.height = val;
        }
        return histogramValues;
    }, { height: 0, histogram: {}, max: -1 });
    const processedPeers = sortedPeers.filter(peer => peer &&
        Math.abs(calculatedHistogramValues.height - peer.height) <
            aggregation + 1);
    if (peerLimit === undefined) {
        return processedPeers;
    }
    if (peerLimit === 1) {
        const goodPeer = [
            processedPeers[Math.floor(Math.random() * processedPeers.length)],
        ];
        return goodPeer;
    }
    return shuffle(processedPeers).slice(0, peerLimit);
};
exports.selectPeersForSend = (input) => shuffle(input.peers).slice(0, input.peerLimit);
exports.selectPeersForConnection = (input) => input.peers;
//# sourceMappingURL=peer_selection.js.map